@@ -30,17 +30,20 @@ ALPHA_NUMERIC = r'\w'
 HEX = r'[0-9A-F]{6}'
 HASHTAG_EXCLUDES = r'%(HEX)s|include' % locals()
 HASHTAG_TEXT = r'%(ALPHA_NUMERIC)s*%(ALPHA)s+%(ALPHA_NUMERIC)s*' % locals()
-HASHTAG_PATTERN = r'(^|[^%(ALPHA_NUMERIC)s&#]+)(#|\uFF03)(?!%(HASHTAG_EXCLUDES)s)(%(HASHTAG_TEXT)s)' % locals()
+HASHTAG_PATTERN = (
+    r'(^|[^%(ALPHA_NUMERIC)s&#])(#|\uFF03)(?!%(HASHTAG_EXCLUDES)s)'
+    '(%(HASHTAG_TEXT)s)' % locals())
 HASHTAG = re.compile(HASHTAG_PATTERN, flags=re.I | re.U)
 
+
 def escape_tag(tag):
     return tag.lower().replace(' ', '_')
 
 
 def get_text_with_dots(text, start, end, found_text=None):
     '''
-    Find the outermost spaces and innermost newlines around (start, end) and add
-    dots if needed.
+    Find the outermost spaces and innermost newlines around
+    (start, end) and add dots if needed.
     '''
     bound1 = max(0, start - int(TEXT_RESULT_LENGTH // 2))
     bound2 = max(0, start)
@@ -84,13 +87,11 @@ def get_text_with_dots(text, start, end, found_text=None):
 
 class Day(object):
     def __init__(self, month, day_number, day_content=None):
-        if day_content is None:
-            day_content = {'text': u''}
-
-        self.date = datetime.date(month.year_number, month.month_number, day_number)
+        day_content = day_content or {'text': u''}
+        assert 'text' in day_content, day_content
 
         self.month = month
-        self.day_number = day_number
+        self.date = datetime.date(month.year_number, month.month_number, day_number)
 
         # Turn all entries of old "Tags" categories into tags without entries.
         old_tags = day_content.pop('Tags', {})
@@ -104,13 +105,9 @@ class Day(object):
         self.last_edit_pos = None
         self.last_preview_pos = None
 
-    # Text
     def _get_text(self):
         '''Return the day's text as unicode.'''
-        if 'text' in self.content:
-            return self.content['text'].decode('utf-8')
-        else:
-            return ''
+        return self.content['text'].decode('utf-8')
 
     def _set_text(self, text):
         self.content['text'] = text
@@ -118,23 +115,19 @@ class Day(object):
 
     @property
     def has_text(self):
-        return len(self.text.strip()) > 0
-
+        # TODO: Don't strip.
+        return bool(self.text.strip())
 
     @property
     def empty(self):
-        if len(self.content) == 0:
-            return True
         return self.content.keys() == ['text'] and not self.has_text
 
-
     def add_category_entry(self, category, entry):
         if category in self.content:
             self.content[category][entry] = None
         else:
             self.content[category] = {entry: None}
 
-
     def merge(self, same_day):
         assert self.date == same_day.date
 
@@ -164,11 +157,8 @@ class Day(object):
     def categories(self):
         return self.get_category_content_pairs().keys()
 
-
     def get_entries(self, category):
-        entries = self.content.get(category) or {}
-        return sorted(entries.keys())
-
+        return sorted(self.content.get(category, {}).keys())
 
     def get_category_content_pairs(self):
         '''
@@ -187,8 +177,8 @@ class Day(object):
             pairs[tag] = []
         return pairs
 
-
     def get_words(self, with_special_chars=False):
+        # TODO: Use str.join().
         all_text = self.text
         for category, content in self.get_category_content_pairs().items():
             all_text += ' ' + ' '.join([category] + content)
@@ -197,17 +187,16 @@ class Day(object):
         if with_special_chars:
             return words
 
-        words = [w.strip(u'.|-!"/()=?*+~#_:;,<>^°´`{}[]\\') for w in words]
+        # Strip all ASCII punctuation except for $, %, @ and '.
+        words = [w.strip(u'.|-!"&/()=?*+~#_:;,<>^°`{}[]\\') for w in words]
         return [word for word in words if word]
 
-
     def get_number_of_words(self):
         return len(self.get_words(with_special_chars=True))
 
-
     def search(self, text, tags):
         """
-        Only days that have all tags are searched.
+        This method is only called for days that have all given tags.
         Search in date first, then in the text, then in the tags.
         Uses case-insensitive search.
         """
@@ -227,9 +216,8 @@ class Day(object):
                         add_text_to_results = True
             if add_text_to_results:
                 results.append(get_text_with_dots(self.text, 0, TEXT_RESULT_LENGTH))
-
         elif text in str(self):
-            # Search in date
+            # Date contains searched text.
             results.append(get_text_with_dots(self.text, 0, TEXT_RESULT_LENGTH))
         else:
             text_result = self.search_in_text(text)
@@ -238,7 +226,6 @@ class Day(object):
             results.extend(self.search_in_categories(text))
         return str(self), results
 
-
     def search_in_text(self, search_text):
         occurence = self.text.upper().find(search_text.upper())
 
@@ -247,12 +234,10 @@ class Day(object):
             return None
 
         found_text = self.text[occurence:occurence + len(search_text)]
-        result_text = get_text_with_dots(self.text, occurence,
-                                         occurence + len(search_text),
-                                         found_text)
+        result_text = get_text_with_dots(
+            self.text, occurence, occurence + len(search_text), found_text)
         return result_text
 
-
     def search_in_categories(self, text):
         results = []
         for category, content in self.get_category_content_pairs().items():
@@ -260,61 +245,46 @@ class Day(object):
                 if text.upper() in category.upper():
                     results.extend(content)
                 else:
-                    results.extend(entry for entry in content
-                                   if text.upper() in entry.upper())
+                    results.extend(
+                        entry for entry in content
+                        if text.upper() in entry.upper())
             elif text.upper() in category.upper():
                 results.append(category)
         return results
 
-
     def __str__(self):
         return self.date.strftime('%Y-%m-%d')
 
-
     def __cmp__(self, other):
         return cmp(self.date, other.date)
 
 
-
 class Month(object):
     def __init__(self, year_number, month_number, month_content=None):
-        if month_content is None:
-            month_content = {}
-
-        self.edited = False
-
         self.year_number = year_number
         self.month_number = month_number
+
+        month_content = month_content or {}
         self.days = {}
         for day_number, day_content in month_content.iteritems():
             self.days[day_number] = Day(self, day_number, day_content)
 
+        self.edited = False
+
     def get_day(self, day_number):
-        if day_number in self.days:
-            return self.days[day_number]
-        else:
-            new_day = Day(self, day_number)
-            self.days[day_number] = new_day
-            return new_day
+        if day_number not in self.days:
+            self.days[day_number] = Day(self, day_number)
+        return self.days[day_number]
 
     def __str__(self):
-        res = 'Month %s %s\n' % (self.year_number, self.month_number)
+        lines = ['Month %s %s' % (self.year_number, self.month_number)]
         for day_number, day in self.days.iteritems():
-            res += '%s: %s\n' % (day_number, day.text)
-        return res
+            lines.append('%s: %s' % (day_number, day.text))
+        return '\n'.join(lines)
 
     @property
     def empty(self):
-        for day in self.days.values():
-            if not day.empty:
-                return False
-        return True
-
-    def same_month(date1, date2):
-        if date1 is None or date2 is None:
-            return False
-        return date1.month == date2.month and date1.year == date2.year
-    same_month = staticmethod(same_month)
+        return all(day.empty for day in self.days.values())
 
     def __cmp__(self, other):
         return cmp((self.year_number, self.month_number),
