@@ -17,12 +17,13 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 # -----------------------------------------------------------------------
 
-import logging
 import datetime
+import logging
 import os
+import webbrowser
 
-import gtk
 import gobject
+import gtk
 
 
 class ActionButton(gtk.Button):
@@ -33,9 +34,7 @@ class ActionButton(gtk.Button):
 
 class UrlButton(ActionButton):
     def __init__(self, text, url):
-        import webbrowser
-        action = lambda x: webbrowser.open(url)
-        ActionButton.__init__(self, text, action)
+        ActionButton.__init__(self, text, lambda _: webbrowser.open(url))
 
 
 class CustomComboBoxEntry(object):
@@ -44,16 +43,15 @@ class CustomComboBoxEntry(object):
 
         self.liststore = gtk.ListStore(gobject.TYPE_STRING)
         self.combo_box.set_model(self.liststore)
-        #self.combo_box.set_wrap_width(5)
         self.combo_box.set_text_column(0)
         self.entry = self.combo_box.get_child()
 
         # Autocompletion
-        self.entry_completion = gtk.EntryCompletion()
-        self.entry_completion.set_model(self.liststore)
-        self.entry_completion.set_minimum_key_length(1)
-        self.entry_completion.set_text_column(0)
-        self.entry.set_completion(self.entry_completion)
+        entry_completion = gtk.EntryCompletion()
+        entry_completion.set_model(self.liststore)
+        entry_completion.set_minimum_key_length(1)
+        entry_completion.set_text_column(0)
+        self.entry.set_completion(entry_completion)
 
     def add_entry(self, entry):
         self.liststore.append([entry])
@@ -215,7 +213,6 @@ class AssistantPage(gtk.VBox):
         self.header.set_markup(text)
 
 
-
 class IntroductionPage(AssistantPage):
     def __init__(self, text, *args, **kwargs):
         AssistantPage.__init__(self, *args, **kwargs)
@@ -225,14 +222,12 @@ class IntroductionPage(AssistantPage):
         self.pack_start(label)
 
 
-
 class RadioButtonPage(AssistantPage):
     def __init__(self, *args, **kwargs):
         AssistantPage.__init__(self, *args, **kwargs)
 
         self.buttons = []
 
-
     def add_radio_option(self, object, label, tooltip=''):
         sensitive = object.is_available()
 
@@ -252,14 +247,12 @@ class RadioButtonPage(AssistantPage):
             description.set_sensitive(sensitive)
             self.pack_start(description, False, False)
 
-
     def get_selected_object(self):
         for button in self.buttons:
             if button.get_active():
                 return button.object
 
 
-
 class PathChooserPage(AssistantPage):
     def __init__(self, assistant, *args, **kwargs):
         AssistantPage.__init__(self, *args, **kwargs)
@@ -273,12 +266,10 @@ class PathChooserPage(AssistantPage):
 
         self.pack_start(self.chooser)
 
-
     def _remove_filters(self):
         for filter in self.chooser.list_filters():
             self.chooser.remove_filter(filter)
 
-
     def prepare(self, porter):
         self._remove_filters()
 
@@ -316,17 +307,14 @@ class PathChooserPage(AssistantPage):
             self.chooser.set_current_folder(dirname)
             self.chooser.set_current_name(filename + '.' + extension)
 
-
     def get_selected_path(self):
         self.last_path = self.chooser.get_filename().decode('utf-8')
         return self.last_path
 
-
     def on_path_changed(self, widget):
         return
 
 
-
 class Assistant(gtk.Assistant):
     def __init__(self, journal, *args, **kwargs):
         gtk.Assistant.__init__(self, *args, **kwargs)
