@@ -51,16 +51,11 @@ class Editor(object):
         self.old_text = ''
         self.search_text = ''
 
-        # Some actions should get a break point even if not much text has been
-        # changed
-        self.force_adding_undo_point = False
-
         # spell checker
         self._spell_checker = None
         self.enable_spell_check(False)
 
         # Enable drag&drop
-        #self.day_text_view.connect('drag-drop', self.on_drop) # unneeded
         self.day_text_view.connect('drag-data-received', self.on_drag_data_received)
 
         # Sometimes making the editor window very small causes the program to freeze
@@ -81,8 +76,6 @@ class Editor(object):
         return self.day_text_buffer.get_text(iter_start, iter_end).decode('utf-8')
 
     def insert(self, text, iter=None, overwrite=False, undoing=False):
-        self.force_adding_undo_point = True
-
         self.day_text_buffer.handler_block(self.changed_connection)
 
         if overwrite:
@@ -100,11 +93,13 @@ class Editor(object):
         self.on_text_change(self.day_text_buffer, undoing=undoing)
 
     def replace_selection(self, text):
-        self.force_adding_undo_point = True
-
+        self.add_undo_point()
+        self.day_text_buffer.handler_block(self.changed_connection)
         self.day_text_buffer.delete_selection(interactive=False,
                                               default_editable=True)
         self.day_text_buffer.insert_at_cursor(text)
+        self.day_text_buffer.handler_unblock(self.changed_connection)
+        self.add_undo_point()
 
     def replace_selection_and_highlight(self, p1, p2, p3):
         """
@@ -132,14 +127,14 @@ class Editor(object):
         variants = set([text, text.capitalize(), text.lower(), text.upper()])
 
         for search_text in variants:
-            iter_tuple = iter_start.forward_search(search_text,
-                                                gtk.TEXT_SEARCH_VISIBLE_ONLY)
+            iter_tuple = iter_start.forward_search(
+                search_text, gtk.TEXT_SEARCH_VISIBLE_ONLY)
 
             # When we find one variant, scroll to it and quit
             if iter_tuple:
                 # It is safer to scroll to a mark than an iter
-                mark = self.day_text_buffer.create_mark('highlight_query',
-                                            iter_tuple[0], left_gravity=False)
+                mark = self.day_text_buffer.create_mark(
+                    'highlight_query', iter_tuple[0], left_gravity=False)
                 self.day_text_view.scroll_to_mark(mark, 0)
                 self.day_text_buffer.delete_mark(mark)
                 return
@@ -151,15 +146,19 @@ class Editor(object):
         else:
             return ''
 
-    def get_text_around_selected_text(self, length):
+    def get_text_left_of_selection(self, length):
         bounds = self.get_selection_bounds()
-        start1 = bounds[0].copy()
-        start1.backward_chars(length)
-        start2 = bounds[0]
-        end1 = bounds[1]
-        end2 = bounds[1].copy()
-        end2.forward_chars(length)
-        return (self.get_text(start1, start2), self.get_text(end1, end2))
+        start = bounds[0].copy()
+        start.backward_chars(length)
+        end = bounds[0]
+        return self.get_text(start, end)
+
+    def get_text_right_of_selection(self, length):
+        bounds = self.get_selection_bounds()
+        start = bounds[1]
+        end = bounds[1].copy()
+        end.forward_chars(length)
+        return self.get_text(start, end)
 
     @staticmethod
     def sort_iters(*iters):
@@ -190,14 +189,41 @@ class Editor(object):
                 self.get_text(sel_start, sel_end),
                 self.get_text(sel_end, end))
 
-    def apply_format(self, markup):
-        text_around_selection = self.get_text_around_selected_text(2)
-        # Apply formatting only once if a format button is clicked multiple times
-        if text_around_selection == (unicode(markup), unicode(markup)):
-            return
+    def _get_markups(self, format, selection):
+        format_to_markups = {
+            'bold': (u'**', u'**'),
+            'italic': (u'//', u'//'),
+            'monospace': (u'``', u'``'),
+            'underline': (u'__', u'__'),
+            'strikethrough': (u'--', u'--'),
+            'title': (u'\n=== ', u' ===\n')
+        }
+        left_markup, right_markup = format_to_markups[format]
+        if format == 'monospace' and '\n' in selection:
+            left_markup = u'\n```\n'
+            right_markup = u'\n```\n'
+        return left_markup, right_markup
 
-        text = self.get_selected_text() or ' '
-        self.replace_selection_and_highlight(markup, text, markup)
+    def apply_format(self, format):
+        selection = self.get_selected_text()
+        left_markup, right_markup = self._get_markups(format, self.get_selected_text())
+
+        # Apply formatting only once.
+        if (self.get_text_left_of_selection(len(left_markup)) == left_markup or
+                selection.startswith(left_markup)):
+            left_markup = ''
+        if (self.get_text_right_of_selection(len(right_markup)) == right_markup or
+                selection.endswith(right_markup)):
+            right_markup = ''
+
+        # Don't add unneeded newlines.
+        if left_markup.startswith('\n') and self.get_text_left_of_selection(1) in ['\n', '']:
+            left_markup = left_markup[1:]
+        if right_markup.endswith('\n') and self.get_text_right_of_selection(1) in ['\n', '']:
+            right_markup = right_markup[:-1]
+
+        text = selection or ' '
+        self.replace_selection_and_highlight(left_markup, text, right_markup)
 
     def set_font(self, font_name):
         font = pango.FontDescription(font_name)
@@ -206,74 +232,81 @@ class Editor(object):
     def hide(self):
         self.day_text_view.hide()
 
-    def on_text_change(self, textbuffer, undoing=False):
-        # Do not record changes while undoing or redoing
-        if undoing:
-            self.old_text = self.get_text()
+    def last_undo_point_is_dirty(self):
+        return self.get_text() != self.old_text
+
+    def add_undo_point(self):
+        if not self.last_undo_point_is_dirty():
             return
 
         new_text = self.get_text()
         old_text = self.old_text[:]
 
-        #Determine whether to add a save point
-        much_text_changed = abs(len(new_text) - len(old_text)) >= 5
+        def undo_func():
+            self.set_text(old_text, undoing=True)
 
-        if much_text_changed or self.force_adding_undo_point:
+        def redo_func():
+            self.set_text(new_text, undoing=True)
 
-            def undo_func():
-                self.set_text(old_text, undoing=True)
+        self.undo_redo_manager.add_action(undo.Action(undo_func, redo_func))
+        self.old_text = new_text
 
-            def redo_func():
-                self.set_text(new_text, undoing=True)
+    def on_text_change(self, textbuffer, undoing=False):
+        # Do not record changes while undoing or redoing.
+        if undoing:
+            self.old_text = self.get_text()
+            return
 
-            action = undo.Action(undo_func, redo_func, 'day_text_field')
-            self.undo_redo_manager.add_action(action)
+        much_text_changed = abs(len(self.get_text()) - len(self.old_text)) >= 5
 
-            self.old_text = new_text
-            self.force_adding_undo_point = False
+        if much_text_changed:
+            self.add_undo_point()
 
-    #===========================================================
-    # Spell check code taken from KeepNote project
+    # ===========================================================
+    # Spell checking.
 
     def can_spell_check(self):
-        """Returns True if spelling is available"""
+        """Return True if spell checking is available."""
         return gtkspell is not None
 
-    def enable_spell_check(self, enabled=True):
-        """Enables/disables spell check"""
+    def is_spell_check_enabled(self):
+        return self._spell_checker is not None
+
+    def _use_system_language_for_spell_check(self):
+        try:
+            self._spell_checker.set_language(filesystem.LANGUAGE)
+        except RuntimeError as err:
+            logging.error('Spellchecking could not be enabled for %s: %s. '
+                          'Consult built-in help for instructions '
+                          'on how to add custom dictionaries.' %
+                          (filesystem.LANGUAGE, err))
+
+    def _enable_spell_check(self):
+        assert self.can_spell_check()
+        assert self._spell_checker is None
+        try:
+            self._spell_checker = gtkspell.Spell(self.day_text_view)
+        except gobject.GError as err:
+            logging.error('Spell checking could not be enabled: %s' % err)
+            self._spell_checker = None
+        else:
+            self._use_system_language_for_spell_check()
+
+    def _disable_spell_check(self):
+        self._spell_checker.detach()
+        self._spell_checker = None
+
+    def enable_spell_check(self, enable=True):
+        """Enable/disable spell check."""
         if not self.can_spell_check():
             return
 
-        if enabled:
-            if self._spell_checker is None:
-                try:
-                    self._spell_checker = gtkspell.Spell(self.day_text_view)
-                except gobject.GError as err:
-                    logging.error('Spell checking could not be enabled: "%s"' % err)
-                    self._spell_checker = None
-                if self._spell_checker:
-                    try:
-                        self._spell_checker.set_language(filesystem.LANGUAGE)
-                    except RuntimeError as err:
-                        logging.error('Spellchecking could not be enabled for %s: %s' %
-                                      (filesystem.LANGUAGE, err))
-                        logging.error('Consult built-in help for instructions '
-                                      'on how to add custom dictionaries.')
-        else:
-            if self._spell_checker is not None:
-                self._spell_checker.detach()
-                self._spell_checker = None
+        if enable and self._spell_checker is None:
+            self._enable_spell_check()
+        elif not enable and self._spell_checker is not None:
+            self._disable_spell_check()
 
-    def is_spell_check_enabled(self):
-        """Returns True if spell check is enabled"""
-        return self._spell_checker is not None
-
-    #===========================================================
-
-    #def on_drop(self, widget, drag_context, x, y, timestamp):
-        #logging.info('Drop occured')
-        #self.day_text_view.emit_stop_by_name('drag-drop')
-        #return True
+    # ===========================================================
 
     def on_drag_data_received(self, widget, drag_context, x, y, selection, info, timestamp):
         # We do not want the default behaviour
