@@ -63,9 +63,10 @@ class InsertMenu(object):
     def __init__(self, main_window):
         self.main_window = main_window
 
-        self.bullet_list = ('\n- %s\n- %s\n  - %s (%s)\n\n\n' %
-                (_('First Item'), _('Second Item'),
-                 _('Indented Item'), _('Two blank lines close the list')))
+        self.bullet_list = (
+            '\n- %s\n- %s\n  - %s (%s)\n\n\n' % (
+                _('First Item'), _('Second Item'), _('Indented Item'),
+                _('Two blank lines close the list')))
 
         self.setup()
 
@@ -85,13 +86,13 @@ class InsertMenu(object):
 
         line = '\n====================\n'
 
-        #table = ('\n|| Whitespace Left | Whitespace Right | Resulting Alignment |\n'
-        #           '| 1               | more than 1     | Align left   |\n'
-        #           '|     more than 1 |               1 |   Align right |\n'
-        #           '|   more than 1   |   more than 1   |   Center   |\n'
-        #           '|| Title rows | are always | centered |\n'
-        #           '|  Use two vertical  |  lines on the left  |  for title rows  |\n'
-        #           '|  Always use  |  at least  |  one whitespace  |\n')
+        # table = ('\n|| Whitespace Left | Whitespace Right | Resulting Alignment |\n'
+        #            '| 1               | more than 1     | Align left   |\n'
+        #            '|     more than 1 |               1 |   Align right |\n'
+        #            '|   more than 1   |   more than 1   |   Center   |\n'
+        #            '|| Title rows | are always | centered |\n'
+        #            '|  Use two vertical  |  lines on the left  |  for title rows  |\n'
+        #            '|  Always use  |  at least  |  one whitespace  |\n')
 
         def tmpl(letter):
             return ''  # return ' (Ctrl+%s)' % letter
@@ -104,22 +105,22 @@ class InsertMenu(object):
             ('File', gtk.STOCK_FILE, _('File'), None,
                 _('Insert a link to a file'),
                 self.get_insert_handler(self.on_insert_file)),
-            ### Translators: Noun
+            # Translators: Noun
             ('Link', gtk.STOCK_JUMP_TO, _('_Link') + tmpl('L'), '<Control>L',
                 _('Insert a link to a website'),
                 self.get_insert_handler(self.on_insert_link)),
             ('BulletList', None, _('Bullet List'), None, None,
                 self.get_insert_handler(self.on_insert_bullet_list)),
-            #('NumberedList', None, _('Numbered List'), None, None,
-            #    self.get_insert_handler(self.on_insert_numbered_list)),
+            # ('NumberedList', None, _('Numbered List'), None, None,
+            #     self.get_insert_handler(self.on_insert_numbered_list)),
             ('Title', None, _('Title'), None, None, self.on_insert_title),
             ('Line', None, _('Line'), None,
                 _('Insert a separator line'),
                 self.get_insert_handler(lambda sel_text: line)),
-            #('Table', None, _('Table'), None, None,
-            #    self.get_insert_handler(lambda sel_text: table)),
-            #('Formula', None, _('Latex Formula'), None, None,
-            #    self.get_insert_handler(self.on_insert_formula)),
+            # ('Table', None, _('Table'), None, None,
+            #     self.get_insert_handler(lambda sel_text: table)),
+            # ('Formula', None, _('Latex Formula'), None, None,
+            #     self.get_insert_handler(self.on_insert_formula)),
             ('Date', None, _('Date/Time') + tmpl('D'), '<Ctrl>D',
                 _('Insert the current date and time (edit format in preferences)'),
                 self.get_insert_handler(self.on_insert_date_time)),
@@ -154,12 +155,13 @@ class InsertMenu(object):
 
     def get_insert_handler(self, func):
         def insert_handler(widget):
-            sel_text = self.main_window.day_text_field.get_selected_text()
+            editor = self.main_window.day_text_field
+            sel_text = editor.get_selected_text()
             repl = func(sel_text)
             if isinstance(repl, basestring):
-                self.main_window.day_text_field.replace_selection(repl)
+                editor.replace_selection(repl)
             elif isinstance(repl, tuple):
-                self.main_window.day_text_field.replace_selection_and_highlight(*repl)
+                editor.replace_selection_and_highlight(*repl)
             else:
                 assert repl is None, repl
         return insert_handler
@@ -260,6 +262,7 @@ class InsertMenu(object):
 
         link_location_entry.set_text('http://')
         link_name_entry.set_text(sel_text)
+        self.main_window.day_text_field.replace_selection('')
 
         def link_entered():
             return bool(link_location_entry.get_text().decode('utf-8'))
@@ -299,17 +302,17 @@ class InsertMenu(object):
             return '\n'.join('- %s' % row for row in sel_text.splitlines())
         return self.bullet_list
 
-    #def on_insert_numbered_list(self, sel_text):
-    #    if sel_text:
-    #        return '\n'.join('+ %s' % row for row in sel_text.splitlines())
-    #    return self.bullet_list.replace('-', '+')
+    # def on_insert_numbered_list(self, sel_text):
+    #     if sel_text:
+    #         return '\n'.join('+ %s' % row for row in sel_text.splitlines())
+    #     return self.bullet_list.replace('-', '+')
 
     def on_insert_title(self, *args):
         self.main_window.day_text_field.apply_format('title')
 
-    #def on_insert_formula(self, sel_text):
-    #    formula = sel_text or '\\sum_{i=1}^n i = \\frac{n(n+1)}{2}'
-    #    return '\\(', formula, '\\)'
+    # def on_insert_formula(self, sel_text):
+    #     formula = sel_text or '\\sum_{i=1}^n i = \\frac{n(n+1)}{2}'
+    #     return '\\(', formula, '\\)'
 
     def on_insert_date_time(self, sel_text):
         format_string = self.main_window.journal.config.read('dateTimeString', '%A, %x %X')
