@@ -38,7 +38,6 @@ from rednotebook.gui import categories
 from rednotebook.gui.exports import ExportAssistant
 from rednotebook.gui import browser
 from rednotebook.gui import search
-from rednotebook.gui.editor import Editor
 from rednotebook.gui import editor
 from rednotebook.gui.clouds import Cloud
 from rednotebook.gui import insert_menu
@@ -67,7 +66,6 @@ class MainWindow(object):
                           'older version of RedNotebook.')
             sys.exit(1)
 
-
         # Get the main window and set the icon
         self.main_frame = self.builder.get_object('main_frame')
         self.main_frame.set_title('RedNotebook')
@@ -100,7 +98,7 @@ class MainWindow(object):
                                         self.undo_redo_manager)
         self.day_text_field.day_text_view.grab_focus()
         can_spell_check = self.day_text_field.can_spell_check()
-        spell_check_enabled = bool(self.journal.config.read('spellcheck', 0))
+        spell_check_enabled = bool(self.journal.config.read('spellcheck'))
         for actiongroup in self.menubar_manager.uimanager.get_action_groups():
             if actiongroup.get_name() == 'MainMenuActionGroup':
                 for action in actiongroup.list_actions():
@@ -213,14 +211,8 @@ class MainWindow(object):
         '''
         This method actually is not responsible for the Ctrl-C etc. actions
         '''
-        self.accel_group = self.builder.get_object('accelgroup1')  # gtk.AccelGroup()
-        #self.accel_group = gtk.AccelGroup()
+        self.accel_group = self.builder.get_object('accelgroup1')
         self.main_frame.add_accel_group(self.accel_group)
-        #self.main_frame.add_accel_group()
-        #for key, signal in [('C', 'copy_clipboard'), ('V', 'paste_clipboard'),
-        #                   ('X', 'cut_clipboard')]:
-        #   self.day_text_field.day_text_view.add_accelerator(signal, self.accel_group,
-        #                   ord(key), gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
 
         self.main_frame.connect('key-press-event', self._on_key_press_event)
 
@@ -228,9 +220,6 @@ class MainWindow(object):
             (self.back_one_day_button, 'clicked', '<Ctrl>Page_Up'),
             (self.today_button, 'clicked', '<Alt>Home'),
             (self.forward_one_day_button, 'clicked', '<Ctrl>Page_Down'),
-            #(self.builder.get_object('undo_menuitem'), 'activate', '<Ctrl>z'),
-            #(self.builder.get_object('redo_menuitem'), 'activate', '<Ctrl>y'),
-            #(self.builder.get_object('options_menuitem'), 'activate', '<Ctrl><Alt>p'),
         ]
         for button, signal, shortcut in shortcuts:
             (keyval, mod) = gtk.accelerator_parse(shortcut)
@@ -242,12 +231,11 @@ class MainWindow(object):
         if event.keyval == gtk.keysyms.Escape and self.is_fullscreen:
             self.toggle_fullscreen()
 
-
     # TRAY-ICON / CLOSE --------------------------------------------------------
 
     def setup_tray_icon(self):
         self.tray_icon = gtk.StatusIcon()
-        visible = (self.journal.config.read('closeToTray', 0) == 1)
+        visible = (self.journal.config.read('closeToTray') == 1)
         self.tray_icon.set_visible(visible)
         logging.debug('Tray icon visible: %s' % visible)
 
@@ -297,8 +285,9 @@ class MainWindow(object):
         # Create a Menu
         menu = self.uimanager.get_widget('/TrayMenu')
 
-        menu.popup(None, None, gtk.status_icon_position_menu,
-                button, activate_time, status_icon)
+        menu.popup(
+            None, None, gtk.status_icon_position_menu, button,
+            activate_time, status_icon)
 
     def show(self):
         self.main_frame.show()
@@ -315,7 +304,7 @@ class MainWindow(object):
         '''
         logging.debug('Main frame destroyed')
 
-        if self.journal.config.read('closeToTray', 0):
+        if self.journal.config.read('closeToTray'):
             self.hide()
         else:
             self.journal.exit()
@@ -332,7 +321,6 @@ class MainWindow(object):
 
     # -------------------------------------------------------- TRAY-ICON / CLOSE
 
-
     def setup_stats_dialog(self):
         self.stats_dialog = self.builder.get_object('stats_dialog')
         self.stats_dialog.set_transient_for(self.main_frame)
@@ -348,7 +336,6 @@ class MainWindow(object):
         for list in [overall_list, day_list]:
             list.set_headers_visible(False)
 
-
     # MODE-SWITCHING -----------------------------------------------------------
 
     def change_mode(self, preview):
@@ -404,7 +391,6 @@ class MainWindow(object):
 
     # ----------------------------------------------------------- MODE-SWITCHING
 
-
     def setup_search(self):
         self.search_tree_view = search.SearchTreeView(self)
         self.search_tree_view.show()
@@ -440,9 +426,6 @@ class MainWindow(object):
             maximized = bool(event.new_window_state & gtk.gdk.WINDOW_STATE_MAXIMIZED)
             self.journal.config['mainFrameMaximized'] = int(maximized)
 
-        # Does not work correctly -> Track fullscreen state in program
-        #self.is_fullscreen = bool(state and gtk.gdk.WINDOW_STATE_FULLSCREEN)
-
     def toggle_fullscreen(self):
         if self.is_fullscreen:
             self.main_frame.unfullscreen()
@@ -461,7 +444,6 @@ class MainWindow(object):
     def on_forward_one_day_button_clicked(self, widget):
         self.journal.go_to_next_day()
 
-
     def on_browser_navigate(self, webview, frame, request):
         '''
         We want to load files and links externally
@@ -477,7 +459,6 @@ class MainWindow(object):
         # Stop processing that event
         return True
 
-
     def get_new_journal_dir(self, title, message):
         dir_chooser = self.builder.get_object('dir_chooser')
         dir_chooser.set_transient_for(self.main_frame)
@@ -498,7 +479,6 @@ class MainWindow(object):
             return new_dir.decode('utf-8')
         return None
 
-
     def show_save_error_dialog(self, exit_imminent):
         dialog = self.builder.get_object('save_error_dialog')
         dialog.set_transient_for(self.main_frame)
@@ -521,7 +501,6 @@ class MainWindow(object):
             self.journal.is_allowed_to_exit = False
         # Do nothing if user wants to exit without saving
 
-
     def add_values_to_config(self):
         config = self.journal.config
 
@@ -541,11 +520,10 @@ class MainWindow(object):
         config.write_list('cloudIgnoreList', sorted(self.cloud.ignore_list))
         config.write_list('cloudIncludeList', sorted(self.cloud.include_list))
 
-
     def load_values_from_config(self):
         config = self.journal.config
-        main_frame_width = config.read('mainFrameWidth', 1024)
-        main_frame_height = config.read('mainFrameHeight', 700)
+        main_frame_width = config.read('mainFrameWidth')
+        main_frame_height = config.read('mainFrameHeight')
 
         screen_width = gtk.gdk.screen_width()
         screen_height = gtk.gdk.screen_height()
@@ -555,12 +533,12 @@ class MainWindow(object):
 
         self.main_frame.resize(main_frame_width, main_frame_height)
 
-        if config.read('mainFrameMaximized', 0):
+        if config.read('mainFrameMaximized'):
             self.main_frame.maximize()
         else:
             # If window is not maximized, restore last position
-            x = config.read('mainFrameX', None)
-            y = config.read('mainFrameY', None)
+            x = config.read('mainFrameX')
+            y = config.read('mainFrameY')
             try:
                 x, y = int(x), int(y)
                 # Set to 0 if value is below 0
@@ -572,7 +550,7 @@ class MainWindow(object):
                 # Values have not been set or are not valid integers
                 self.main_frame.set_position(gtk.WIN_POS_CENTER)
 
-        self.builder.get_object('main_pane').set_position(config.read('leftDividerPosition', 250))
+        self.builder.get_object('main_pane').set_position(config.read('leftDividerPosition'))
         # By default do not show tags pane.
         self.edit_pane.set_position(config.read('rightDividerPosition', main_frame_width))
 
@@ -586,12 +564,13 @@ class MainWindow(object):
         def update_menu(button):
             self.template_button.set_menu(self.template_manager.get_menu())
 
-        self.template_button = customwidgets.ToolbarMenuButton(gtk.STOCK_PASTE,
-                                        self.template_manager.get_menu())
+        self.template_button = customwidgets.ToolbarMenuButton(
+            gtk.STOCK_PASTE, self.template_manager.get_menu())
         self.template_button.set_label(_('Template'))
         self.template_button.connect('show-menu', update_menu)
-        self.template_button.set_tooltip_text(_("Insert this weekday's template. "
-                        "Click the arrow on the right for more options"))
+        self.template_button.set_tooltip_text(_(
+            "Insert this weekday's template. "
+            "Click the arrow on the right for more options"))
         self.builder.get_object('edit_toolbar').insert(self.template_button, 2)
 
     def on_add_new_entry_button_clicked(self, widget):
@@ -663,9 +642,9 @@ class Preview(browser.HtmlView):
             gobject.idle_add(self.get_vscrollbar().set_value, y)
 
 
-class DayEditor(Editor):
+class DayEditor(editor.Editor):
     def __init__(self, *args, **kwargs):
-        Editor.__init__(self, *args, **kwargs)
+        editor.Editor.__init__(self, *args, **kwargs)
         self.day = None
         self.scrolled_win = self.day_text_view.get_parent()
 
@@ -818,7 +797,7 @@ class Calendar(object):
         self.journal = journal
         self.calendar = calendar
 
-        week_numbers = self.journal.config.read('weekNumbers', 0)
+        week_numbers = self.journal.config.read('weekNumbers')
         if week_numbers:
             calendar.set_property('show-week-numbers', True)
 
@@ -885,7 +864,8 @@ class Calendar(object):
         cal_year, cal_month, cal_day = self.calendar.get_date()
         cal_month += 1
         if day_number not in range(1, dates.get_number_of_days(cal_year, cal_month) + 1):
-            logging.debug('Non-existent date in calendar: %s.%s.%s' %
-                        (day_number, cal_month, cal_year))
+            logging.debug(
+                'Non-existent date in calendar: %s.%s.%s' %
+                (day_number, cal_month, cal_year))
             return False
         return True
