@@ -28,6 +28,7 @@ from rednotebook.gui.customwidgets import ActionButton
 from rednotebook.gui import editor
 from rednotebook.util import filesystem, utils, dates
 from rednotebook import info
+from rednotebook.configuration import Config
 
 
 class Option(gtk.HBox):
@@ -160,7 +161,7 @@ class DateFormatOption(ComboBoxOption):
     def on_format_changed(self, widget):
         format_string = self.get_value()
         date_string = dates.format_date(format_string)
-        ### Translators: Noun
+        # Translators: Noun
         label_text = u'%s %s' % (_('Preview:'), date_string)
         self.preview.set_text(label_text)
 
@@ -266,7 +267,8 @@ class OptionsManager(object):
         # application keeps on running in the background after it has been
         # closed. The option can still be activated in the configuration file.
         if filesystem.has_system_tray():
-            self.options.append(TickOption(_('Close to system tray'), 'closeToTray',
+            self.options.append(TickOption(
+                _('Close to system tray'), 'closeToTray',
                 tooltip=_('Closing the window will send RedNotebook to the tray')))
 
         # Automatic switching between preview and edit mode.
@@ -290,7 +292,7 @@ class OptionsManager(object):
             # Use separate fonts since the preview often doesn't support the edit font.
             FontOption(_('Edit font:'), 'mainFont'),
             TextOption(_('Preview font:'), 'previewFont',
-                       default='Ubuntu, sans-serif',
+                       default=Config.defaults['previewFont'],
                        tooltip=_('Comma-separated font names')),
             DateFormatOption(_('Date/Time format'), 'dateTimeString'),
             TextOption(_('Exclude from cloud'), 'cloudIgnoreList',
@@ -299,7 +301,6 @@ class OptionsManager(object):
                        tooltip=_('Allow these words with 4 letters or less')),
         ])
 
-
         self.add_all_options()
 
         response = self.dialog.run()
@@ -311,7 +312,7 @@ class OptionsManager(object):
             self.main_window.cloud.update_lists()
             self.main_window.cloud.update(force_update=True)
 
-            visible = (self.config.read('closeToTray', 0) == 1)
+            visible = (self.config.read('closeToTray') == 1)
             self.main_window.tray_icon.set_visible(visible)
         else:
             # Reset some options
