@@ -22,27 +22,20 @@ This module takes the ideas and some code from the highlighting module
 PyGTKCodeBuffer by Hannes Matuschek (http://code.google.com/p/pygtkcodebuffer/).
 """
 
+import collections
+import re
+
 import gtk
 import pango
 
-import collections
-import logging
-import os
-import re
-import sys
-
-if __name__ == '__main__':
-    sys.path.insert(0, os.path.abspath("./../../"))
-    logging.getLogger('').setLevel(logging.DEBUG)
-
 from rednotebook.data import HASHTAG
 from rednotebook.external import txt2tags
-from rednotebook.gui.browser import HtmlView
 from rednotebook.util import markup
 
 
 Tag = collections.namedtuple('Tag', ['start', 'end', 'name', 'rule'])
 
+
 class TagGroup(list):
     @property
     def min_start(self):
@@ -152,8 +145,9 @@ class MarkupBuffer(gtk.TextBuffer):
     def set_search_text(self, text):
         if not text:
             self._lang_def.highlight_rule = None
-        self._lang_def.highlight_rule = Pattern(r"(%s)" % re.escape(text),
-                            [(1, 'highlight')], name='highlight', flags='I')
+        self._lang_def.highlight_rule = Pattern(
+            r"(%s)" % re.escape(text),
+            [(1, 'highlight')], name='highlight', flags='I')
         self.update_syntax(self.get_start_iter(), self.get_end_iter())
 
     def get_slice(self, start, end):
@@ -212,25 +206,27 @@ class MarkupBuffer(gtk.TextBuffer):
 
 
 styles = {
-    'bold':             {'weight': pango.WEIGHT_BOLD},
-    'italic':           {'style': pango.STYLE_ITALIC},
-    'underline':        {'underline': pango.UNDERLINE_SINGLE},
-    'strikethrough':    {'strikethrough': True},
-    'gray':             {'foreground': 'gray'},
-    'red':              {'foreground': 'red'},
-    'green':            {'foreground': 'darkgreen'},
-    'raw':              {'font': 'Oblique'},
-    'verbatim':         {'font': 'monospace'},
-    'tagged':           {},
-    'link':             {'foreground': 'blue',
-                         'underline': pango.UNDERLINE_SINGLE},
-    'highlight':        {'background': 'yellow'},
-    'quote':            {'background': 'gray'},
-    'tablehead':        {'background': markup.TABLE_HEAD_BG},
-    'tablerow':         {'background': '#eee'},
-    'formula':          {'style': pango.STYLE_ITALIC, 'family': 'serif'}
+    'bold': {'weight': pango.WEIGHT_BOLD},
+    'italic': {'style': pango.STYLE_ITALIC},
+    'underline': {'underline': pango.UNDERLINE_SINGLE},
+    'strikethrough': {'strikethrough': True},
+    'gray': {'foreground': 'gray'},
+    'red': {'foreground': 'red'},
+    'green': {'foreground': 'darkgreen'},
+    'raw': {'font': 'Oblique'},
+    'verbatim': {'font': 'monospace'},
+    'tagged': {},
+    'link': {
+        'foreground': 'blue',
+        'underline': pango.UNDERLINE_SINGLE},
+    'highlight': {'background': 'yellow'},
+    'quote': {'background': 'gray'},
+    'tablehead': {'background': markup.TABLE_HEAD_BG},
+    'tablerow': {'background': '#eee'},
+    'formula': {'style': pango.STYLE_ITALIC, 'family': 'serif'}
 }
 
+
 def add_header_styles():
     sizes = [
         pango.SCALE_XX_LARGE,
@@ -240,8 +236,9 @@ def add_header_styles():
         pango.SCALE_SMALL,
     ]
     for level, size in enumerate(sizes):
-        style = {'weight': pango.WEIGHT_ULTRABOLD,
-                'scale': size}
+        style = {
+            'weight': pango.WEIGHT_ULTRABOLD,
+            'scale': size}
         name = 'title%s' % (level + 1)
         styles[name] = style
 
@@ -251,6 +248,7 @@ add_header_styles()
 
 bank = txt2tags.getRegexes()
 
+
 def get_pattern(char, style):
     # original strikethrough in txt2tags: r'--([^\s](|.*?[^\s])-*)--'
     # txt2tags docs say that format markup is greedy, but
@@ -285,20 +283,22 @@ for level in range(1, 6):
 linebreak = Pattern(r'(%s)' % markup.REGEX_LINEBREAK, [(1, 'gray')])
 
 # pic [""/home/user/Desktop/RedNotebook pic"".png]
-pic = Pattern(markup.REGEX_PIC.pattern,
-        [(1, 'gray'), (2, 'green'), (3, 'gray'), (4, 'green'), (5, 'gray'), (6, 'gray')], flags='I')
+pic = Pattern(
+    markup.REGEX_PIC.pattern,
+    [(1, 'gray'), (2, 'green'), (3, 'gray'), (4, 'green'), (5, 'gray'), (6, 'gray')], flags='I')
 
 # named local link [my file.txt ""file:///home/user/my file.txt""]
 # named link in web [heise ""http://heise.de""]
-named_link = Pattern(markup.REGEX_NAMED_LINK,
-        [(1, 'gray'), (2, 'link'), (3, 'gray'), (4, 'gray'), (5, 'gray')])
+named_link = Pattern(
+    markup.REGEX_NAMED_LINK,
+    [(1, 'gray'), (2, 'link'), (3, 'gray'), (4, 'gray'), (5, 'gray')])
 
 # link http://heise.de
 # Use txt2tags link guessing mechanism by setting regex explicitly
 link = Pattern(bank['link'], [(0, 'link')], name='link')
 
-# We do not support multiline regexes
-#blockverbatim = Pattern(r'^(```)\s*$\n(.*)$\n(```)\s*$', [(1, 'gray'), (2, 'verbatim'), (3, 'gray')])
+# TODO: Support multiline regexes.
+# blockverbatim = Pattern(r'^(```)\s*$\n(.*)$\n(```)\s*$', [(1, 'gray'), (2, 'verbatim'), (3, 'gray')])
 
 quote = Pattern(r'^\t+(.*)$', [(1, 'quote')])
 
@@ -342,85 +342,3 @@ def get_highlight_buffer():
     buff = MarkupBuffer(lang=lang, styles=styles)
 
     return buff
-
-# Testing
-if __name__ == '__main__':
-
-    txt = """aha**aha**
-
-**a//b//c** //a**b**c// __a**b**c__ __a//b//c__
-
-text [link 1 ""http://en.wikipedia.org/wiki/Personal_wiki#Free_software""] another text
-[link2 ""http://digitaldump.wordpress.com/projects/rednotebook/""] end
-
-pic [""/home/user/Desktop/RedNotebook pic"".png] pic [""/home/user/Desktop/RedNotebook pic"".png]
-== Main==[oho]
-= Header1 =
-== Header2 ==
-=== Header3 ===
-==== Header4 ====
-===== Header5 =====
-+++++ d +++++
-++++ c ++++
-+++ a +++
-++ b ++
- **bold**, //italic//,/italic/__underlined__, --strikethrough--
-
-[""/home/user/Desktop/RedNotebook pic"".png]
-
-[hs error.log ""file:///home/user/hs error.log""]
-```
-[heise ""http://heise.de""]
-```
-www.heise.de, andy@web.de
-
-''$a^2$''  ""über oblique""  ``code mit python``
-
-====================
-
-% list-support
-- a simple list item
-- an other
-
-
-+ An ordered list
-+ other item
-
-
-"""
-    #txt = '- an other'
-
-    search_text = 'aha'
-
-    buff = get_highlight_buffer()
-
-    buff.set_search_text(search_text)
-
-    win = gtk.Window(gtk.WINDOW_TOPLEVEL)
-    scr = gtk.ScrolledWindow()
-
-    html_editor = HtmlView()
-
-    def change_text(widget):
-        html = markup.convert(widget.get_text(widget.get_start_iter(),
-                              widget.get_end_iter()), 'xhtml', '/tmp')
-
-        html_editor.load_html(html)
-        html_editor.highlight(search_text)
-
-    buff.connect('changed', change_text)
-
-    vbox = gtk.VBox()
-    vbox.pack_start(scr)
-    vbox.pack_start(html_editor)
-    win.add(vbox)
-    scr.add(gtk.TextView(buff))
-
-    win.set_default_size(900, 1000)
-    win.set_position(gtk.WIN_POS_CENTER)
-    win.show_all()
-    win.connect("destroy", lambda w: gtk.main_quit())
-
-    buff.set_text(txt)
-
-    gtk.main()
