@@ -37,9 +37,11 @@ IS_WIN = sys.platform.startswith('win')
 def get_unicode_path(path):
     return unicode(path, ENCODING)
 
+
 def get_utf8_path(path):
     return path.encode('UTF-8')
 
+
 def has_system_tray():
     return IS_WIN  # A smarter detection is needed here ;)
 
@@ -78,7 +80,7 @@ class Filenames(dict):
                 self[key] = value
                 setattr(self, key, value)
 
-        self.portable = bool(config.read('portable', 0))
+        self.portable = bool(config.read('portable'))
 
         self.journal_user_dir = self.get_user_dir(config)
 
@@ -94,9 +96,8 @@ class Filenames(dict):
 
         self.forbidden_dirs = [user_home_dir, self.journal_user_dir]
 
-
     def get_user_dir(self, config):
-        custom = config.read('userDir', '')
+        custom = config.read('userDir')
 
         if custom:
             # If a custom user dir has been set,
@@ -113,11 +114,9 @@ class Filenames(dict):
 
         return user_dir
 
-
     def is_valid_journal_path(self, path):
         return os.path.isdir(path) and os.path.abspath(path) not in self.forbidden_dirs
 
-
     def __getattribute__(self, attr):
         user_paths = dict((
             ('template_dir', 'templates'),
@@ -133,17 +132,15 @@ class Filenames(dict):
         return dict.__getattribute__(self, attr)
 
 
-
 def read_file(filename):
-    '''Tries to read a given file
+    """Try to read a given file.
 
-    Returns None if an error is encountered
-    '''
+    Return None if an error is encountered.
+    """
     encodings = ['utf-8']
 
     try:
         import chardet
-        assert chardet  # silence pyflakes
     except ImportError:
         logging.info("chardet not found. 'utf-8' encoding will be assumed")
         chardet = None
@@ -191,23 +188,28 @@ def make_directory(dir):
     if not os.path.isdir(dir):
         os.makedirs(dir)
 
+
 def make_directories(dirs):
     for dir in dirs:
         make_directory(dir)
 
+
 def make_file(file, content=''):
     if not os.path.isfile(file):
         write_file(file, content)
 
+
 def make_files(file_content_pairs):
     for file, content in file_content_pairs:
         make_file(file, content)
 
+
 def make_file_with_dir(file, content):
     dir = os.path.dirname(file)
     make_directory(dir)
     make_file(file, content)
 
+
 def get_relative_path(from_dir, to_dir):
     '''
     Try getting the relative path from from_dir to to_dir
@@ -317,6 +319,7 @@ def _open_url_with_call(url, prog):
         # If everything failed, try the webbrowser
         open_url_in_browser(url)
 
+
 def open_url(url):
     '''
     Opens a file with the platform's preferred method
@@ -340,12 +343,3 @@ def open_url(url):
         _open_url_with_call(url, 'open')
     else:
         _open_url_with_call(url, 'xdg-open')
-
-
-
-if __name__ == '__main__':
-    dirs = ['/home/my journal', '/my journal/', r'C:\\Dok u E\journal',
-            '/home/name/journal', '/']
-    for dir in dirs:
-        title = get_journal_title(dir)
-        print '%s -> %s' % (dir, title)
