@@ -25,12 +25,6 @@ import sys
 import gobject
 import pango
 
-# Testing
-if __name__ == '__main__':
-    sys.path.insert(0, '../../')
-    logging.basicConfig(level=logging.DEBUG,
-                    format='%(levelname)-8s %(message)s',)
-
 from rednotebook.external import txt2tags
 from rednotebook.data import HASHTAG
 from rednotebook.util import filesystem
@@ -179,10 +173,9 @@ def get_markup_for_day(day, with_text=True, with_tags=True, categories=None, dat
         # "Export no categories" selected
         export_categories = []
 
-
     if export_categories:
-        export_string += '\n\n\n' + convert_categories_to_markup(export_categories,
-                                                            with_category_title=with_text)
+        export_string += '\n\n\n' + convert_categories_to_markup(
+            export_categories, with_category_title=with_text)
     elif with_text:
         export_string += '\n\n'
 
@@ -250,7 +243,6 @@ def _get_config(target, options):
 
         # For images we have to omit the file:// prefix
         config['postproc'].append([r'includegraphics\{(.*)"%s' % scheme, r'includegraphics{"\1'])
-        #config['postproc'].append([r'includegraphics\{"file://', r'includegraphics{"'])
 
         # Special handling for LOCAL file links (Omit scheme, add run:)
         # \htmladdnormallink{file.txt}{file:///home/user/file.txt}
@@ -387,7 +379,8 @@ def convert(txt, target, data_dir, headers=None, options=None):
         result = msg
     # Unknown error, show the traceback to the user
     except:
-        result = ('<b>Error</b>: This day contains invalid '
+        result = (
+            '<b>Error</b>: This day contains invalid '
             '<a href="http://txt2tags.org/markup.html">txt2tags markup</a>. '
             'You can help us fix this by submitting a bugreport in the '
             '<a href="https://code.google.com/p/txt2tags/issues/list">'
@@ -483,10 +476,3 @@ def convert_from_pango(pango_markup):
     logging.log(5, 'Converted "%s" pango to "%s" txt2tags' %
                 (repr(original_txt), repr(pango_markup)))
     return pango_markup
-
-
-if __name__ == '__main__':
-    from rednotebook.util.utils import show_html_in_browser
-    markup = 'Aha\n\tThis is a quote. It looks very nice. Even with many lines'
-    html = convert(markup, 'xhtml', '/tmp')
-    show_html_in_browser(html, '/tmp/test.html')
